Struct ResponseAxumBodyLayer
pub struct ResponseAxumBodyLayer;Expand description
Layer that transforms the Response body to crate::body::Body.
This is useful when another layer maps the body to some other type to convert it back.